servicex_matching v0.0.1 ServicexMatchingWeb.Router.Helpers
Module with named helpers generated from ServicexMatchingWeb.Router.
Link to this section Summary
Functions
Generates the path information including any necessary prefix
Generates path to a static asset given its file path
Generates url to a static asset given its file path
Generates the connection/endpoint base URL without any path information
Link to this section Functions
Link to this function
application_path(conn_or_endpoint, action)
Link to this function
application_path(conn_or_endpoint, action, params)
Link to this function
application_path(conn_or_endpoint, action, id, params)
Link to this function
application_url(conn_or_endpoint, action)
Link to this function
application_url(conn_or_endpoint, action, params)
Link to this function
application_url(conn_or_endpoint, action, id, params)
Link to this function
authenticator_path(conn_or_endpoint, action)
Link to this function
authenticator_path(conn_or_endpoint, action, params)
Link to this function
authenticator_url(conn_or_endpoint, action)
Link to this function
authenticator_url(conn_or_endpoint, action, params)
Link to this function
organization_path(conn_or_endpoint, action)
Link to this function
organization_path(conn_or_endpoint, action, params)
Link to this function
organization_path(conn_or_endpoint, action, id, params)
Link to this function
organization_url(conn_or_endpoint, action)
Link to this function
organization_url(conn_or_endpoint, action, params)
Link to this function
organization_url(conn_or_endpoint, action, id, params)
Link to this function
path(data, path)
Generates the path information including any necessary prefix.
Link to this function
project_path(conn_or_endpoint, action)
Link to this function
project_path(conn_or_endpoint, action, params)
Link to this function
project_path(conn_or_endpoint, action, id, params)
Link to this function
project_url(conn_or_endpoint, action)
Link to this function
project_url(conn_or_endpoint, action, params)
Link to this function
project_url(conn_or_endpoint, action, id, params)
Link to this function
record_path(conn_or_endpoint, action)
Link to this function
record_path(conn_or_endpoint, action, params)
Link to this function
record_path(conn_or_endpoint, action, id, params)
Link to this function
record_url(conn_or_endpoint, action)
Link to this function
record_url(conn_or_endpoint, action, params)
Link to this function
record_url(conn_or_endpoint, action, id, params)
Link to this function
static_path(conn, path)
Generates path to a static asset given its file path.
Link to this function
static_url(conn, path)
Generates url to a static asset given its file path.
Link to this function
tag_path(conn_or_endpoint, action)
Link to this function
tag_path(conn_or_endpoint, action, params)
Link to this function
tag_path(conn_or_endpoint, action, id, params)
Link to this function
tag_url(conn_or_endpoint, action)
Link to this function
tag_url(conn_or_endpoint, action, params)
Link to this function
tag_url(conn_or_endpoint, action, id, params)
Link to this function
url(data)
Generates the connection/endpoint base URL without any path information.
Link to this function
user_profile_path(conn_or_endpoint, action)
Link to this function
user_profile_path(conn_or_endpoint, action, params)
Link to this function
user_profile_path(conn_or_endpoint, action, id, params)
Link to this function
user_profile_url(conn_or_endpoint, action)
Link to this function
user_profile_url(conn_or_endpoint, action, params)
Link to this function
user_profile_url(conn_or_endpoint, action, id, params)